| Title: | Exposome and omic data associatin and integration analysis |
|---|---|
| Description: | omicRexposome systematizes the association evaluation between exposures and omic data, taking advantage of MultiDataSet for coordinated data management, rexposome for exposome data definition and limma for association testing. Also to perform data integration mixing exposome and omic data using multi co-inherent analysis (omicade4) and multi-canonical correlation analysis (PMA). |
| Authors: | Carles Hernandez-Ferrer [aut, cre], Juan R. González [aut] |
| Maintainer: | Xavier Escribà Montagut <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.35.0 |
| Built: | 2026-05-23 15:24:40 UTC |
| Source: | https://github.com/bioc/omicRexposome |
This method allows to insert an object of class ExposomeClust as an independent dataset into an object of class MultiDataSet.
add_cls(object, clsSet, ...) ## S4 method for signature 'MultiDataSet,ExposomeClust' add_cls(object, clsSet, ...)add_cls(object, clsSet, ...) ## S4 method for signature 'MultiDataSet,ExposomeClust' add_cls(object, clsSet, ...)
object |
An object of class MultiDataSet. |
clsSet |
An object of class ExposomeClust. |
... |
Arguments given to add_eset from MultiDataSet. |
A MultiDataSet with the ExpressionSet added as an independent dataset.
data("eclust", package = "rexposome") library(MultiDataSet) md <- new("MultiDataSet") names(md) md <- add_cls(md, expo_c) names(md)data("eclust", package = "rexposome") library(MultiDataSet) md <- new("MultiDataSet") names(md) md <- add_cls(md, expo_c) names(md)
This method allows to insert an object of class ExposomeSet as an independent dataset into an object of class MultiDataSet.
add_exp(object, expoSet, warnings = TRUE, ...) ## S4 method for signature 'MultiDataSet,ExposomeSet' add_exp(object, expoSet, warnings = TRUE, ...)add_exp(object, expoSet, warnings = TRUE, ...) ## S4 method for signature 'MultiDataSet,ExposomeSet' add_exp(object, expoSet, warnings = TRUE, ...)
object |
An object of class MultiDataSet. |
expoSet |
An object of class ExposomeSet. |
warnings |
(default |
... |
Arguments given to add_eset from MultiDataSet. |
A MultiDataSet with the ExpressionSet added as an independent dataset.
data("exposome", package = "rexposome") library(MultiDataSet) md <- new("MultiDataSet") names(md) md <- add_exp(md, expo) names(md)data("exposome", package = "rexposome") library(MultiDataSet) md <- new("MultiDataSet") names(md) md <- add_exp(md, expo) names(md)
ResultSet for testing and illustration purpousesResultSet created using association method, testing
proteome association to exposome ("mds"), adjusted by sex and age.
data("asr")data("asr")
An object of class ResultSet of length 15.
A ResultSet object.
data("asr", package = "omicRexposome") asrdata("asr", package = "omicRexposome") asr
This function allows to perform an association study between gene
expression from microarray and the exposome. An ExpresionSet is
the object storing the gene expresion and an ExposomeSet the one
storing the exposome. Both of them needs to be encapsulated in a
MultiDataSet. The association study is perform through standard
limma pipeline. The function allows to perform multiple tests using
the argument exposures.
association(object, formula, expset, omicset, set = "exposures", method = "ls", ..., baselevels, sva = "none", vfilter = NULL, verbose = FALSE, warnings = TRUE) ## S4 method for signature 'MultiDataSet' association(object, formula, expset, omicset, set = "exposures", method = "ls", ..., baselevels, sva = "none", vfilter = NULL, verbose = FALSE, warnings = TRUE)association(object, formula, expset, omicset, set = "exposures", method = "ls", ..., baselevels, sva = "none", vfilter = NULL, verbose = FALSE, warnings = TRUE) ## S4 method for signature 'MultiDataSet' association(object, formula, expset, omicset, set = "exposures", method = "ls", ..., baselevels, sva = "none", vfilter = NULL, verbose = FALSE, warnings = TRUE)
object |
A |
formula |
formula to be evaluated by each exposure (or phenotype, see
|
expset |
Name of the |
omicset |
Name of the omic data-set in |
set |
(default |
method |
(default |
... |
Arguments passed to |
baselevels |
(optional) If set, must be a labeled vector with the default base level for categorical exposures. |
sva |
(default |
vfilter |
(default |
verbose |
(default |
warnings |
(default |
An object of class ResultSet.
library(MultiDataSet) data(brge_prot, package = "brgedata") data(brge_expo, package = "brgedata") mds <- createMultiDataSet() mds <- add_eset(mds, brge_prot, dataset.type = "proteines") mds <- add_eset(mds, brge_expo, dataset.type = "exposures", GRanges = NA) asr <- association(mds, formula = Asthma ~ Sex + Age, expset = "exposures", omicset = "proteines") asrlibrary(MultiDataSet) data(brge_prot, package = "brgedata") data(brge_expo, package = "brgedata") mds <- createMultiDataSet() mds <- add_eset(mds, brge_prot, dataset.type = "proteines") mds <- add_eset(mds, brge_expo, dataset.type = "exposures", GRanges = NA) asr <- association(mds, formula = Asthma ~ Sex + Age, expset = "exposures", omicset = "proteines") asr
This function allows to perform a Transcriptome-Wide Association Study
by using an ExposmeSet and an ExpressionSet. It
allows to perform an adjustment using Surrogate Variable Analysis (from
R package sva).
crossomics(object, method = "mcca", ncomponents = 2, ..., na.rm = FALSE, permute = c(100, 3), verbose = FALSE, warnings = TRUE) ## S4 method for signature 'MultiDataSet' crossomics(object, method = "mcca", ncomponents = 2, ..., na.rm = FALSE, permute = c(100, 3), verbose = FALSE, warnings = TRUE)crossomics(object, method = "mcca", ncomponents = 2, ..., na.rm = FALSE, permute = c(100, 3), verbose = FALSE, warnings = TRUE) ## S4 method for signature 'MultiDataSet' crossomics(object, method = "mcca", ncomponents = 2, ..., na.rm = FALSE, permute = c(100, 3), verbose = FALSE, warnings = TRUE)
object |
A |
method |
(default |
ncomponents |
(default |
... |
Other arguments given to |
na.rm |
(default |
permute |
(default |
verbose |
(default |
warnings |
(default |
An object of class ResultSet.
library(MultiDataSet) library(rexposome) data(brge_prot, package = "brgedata") data(brge_expo, package = "brgedata") mds <- createMultiDataSet() mds <- add_eset(mds, brge_prot, dataset.type = "proteines") mds <- add_eset(mds, imputation(brge_expo), dataset.type = "exposures", GRanges = NA) crs <- crossomics(mds, method = "mcia") crslibrary(MultiDataSet) library(rexposome) data(brge_prot, package = "brgedata") data(brge_expo, package = "brgedata") mds <- createMultiDataSet() mds <- add_eset(mds, brge_prot, dataset.type = "proteines") mds <- add_eset(mds, imputation(brge_expo), dataset.type = "exposures", GRanges = NA) crs <- crossomics(mds, method = "mcia") crs
ResultSet for testing and illustration purpousesResultSet created using crossomics method, selecting
"mcia" method. Result from the integration of proteome and
exposome data ("mds").
data("crs")data("crs")
An object of class ResultSet of length 1.
A ResultSet object.
data("crs", package = "omicRexposome") crsdata("crs", package = "omicRexposome") crs
Homologous methods from MultiDataSet (getAssociation) but
for ResultsSet created by crossomics. It Resturns a
data.frame with the result from mcia (omicade4) or
from MultiCCA (PMA).
getIntegration(object, ...) ## S4 method for signature 'ResultSet' getIntegration(object, ...)getIntegration(object, ...) ## S4 method for signature 'ResultSet' getIntegration(object, ...)
object |
An object of class ResultSet obtained from |
... |
NOT USED |
A data.frame
data("crs", package = "omicRexposome") class(getIntegration(crs))data("crs", package = "omicRexposome") class(getIntegration(crs))
MultiDataSet for testing and illustration purpousesMultiDataSet containing both proteome data-set and exposome
data-set.
data("mds")data("mds")
An object of class MultiDataSet of length 2.
A MultiDataSet object.
data("mds", package = "omicRexposome") mdsdata("mds", package = "omicRexposome") mds
omicRexposome: Package for exposome and omic data associatin and integration
The packages offers the function association that allows to
perform an association study using transcriptome, methylome, etc. as
dependent variable and exposome data as independent variable. The function relies on
limma pipeline and generates an object of class ResultSet,
that can be ploted using plotAssociation.
The packages offers the function crossomics that allows to perform
two types of integration study: Multi Canonical Correlation Analysis and
Multi Co-Inertia Analysis. The function allos to use any type and number of
datasets (aka. exposome transcriptome, methylome, etc.). The function generates an
object of class ResultSet, that can be ploted using
plotIntegration.
This function draws two type of plots for the ResultSet from association functions
plotAssociation(object, rid = 1, coef = 2, contrast = 1, type = c("manhattan", "qq", "volcano"), tPV = NULL, tFC = NULL, show.effect = FALSE) ## S4 method for signature 'ResultSet' plotAssociation(object, rid = 1, coef = 2, contrast = NULL, type = c("manhattan", "qq", "volcano"), tPV = NULL, tFC = NULL, show.effect = FALSE)plotAssociation(object, rid = 1, coef = 2, contrast = 1, type = c("manhattan", "qq", "volcano"), tPV = NULL, tFC = NULL, show.effect = FALSE) ## S4 method for signature 'ResultSet' plotAssociation(object, rid = 1, coef = 2, contrast = NULL, type = c("manhattan", "qq", "volcano"), tPV = NULL, tFC = NULL, show.effect = FALSE)
object |
An object of class ResultSet obtained from assoc_* functions. |
rid |
(default |
coef |
(default |
contrast |
(default |
type |
Can take |
tPV |
(optional) Threshold for P.Value when |
tFC |
(optional) Threshold for Fold Change or Effect when
|
show.effect |
(default |
A ggplot2 object
plotIntegration for plotting integration results.
association to create a ResultSet to be passed to
this function.
data("asr", package = "omicRexposome") plotAssociation(asr, type = "qq") plotAssociation(asr, type = "volcano")data("asr", package = "omicRexposome") plotAssociation(asr, type = "qq") plotAssociation(asr, type = "volcano")
This method draws a barplot with the number of hits in each result stored in the given ResultSet.
plotHits(object, th = 0.05, width = 0.75) ## S4 method for signature 'ResultSet' plotHits(object, th = 0.05, width = 0.75)plotHits(object, th = 0.05, width = 0.75) ## S4 method for signature 'ResultSet' plotHits(object, th = 0.05, width = 0.75)
object |
An object of class ResultSet |
th |
(default |
width |
(default |
A ggplot2 object
plotLambda for a graphical representation of
the lambda score per analysys, tableLambda for the lambda
score per analysys, tableHits for the hists per analysys
data(asr, package = "omicRexposome") plotHits(asr)data(asr, package = "omicRexposome") plotHits(asr)
This function draws a plots for the ResultSet from integration function
plotIntegration(object, cmpX = 1, cmpY = 2, lb.th = 0.2, legend.show = TRUE, colors, ...) ## S4 method for signature 'ResultSet' plotIntegration(object, cmpX = 1, cmpY = 2, lb.th = 0.2, legend.show = TRUE, colors, ...)plotIntegration(object, cmpX = 1, cmpY = 2, lb.th = 0.2, legend.show = TRUE, colors, ...) ## S4 method for signature 'ResultSet' plotIntegration(object, cmpX = 1, cmpY = 2, lb.th = 0.2, legend.show = TRUE, colors, ...)
object |
An object of class ResultSet obtained from crossomics. |
cmpX |
(default |
cmpY |
(default |
lb.th |
(default |
legend.show |
(default |
colors |
(optional) Names vector with the colors sued to draw each dataset. Used when ploting results from MultiCCA. If missing, random colores are chosen. |
... |
Optional arguments are given to |
A ggplot2 object
plotAssociation for plotting association results.
crossomics to create a ResultSet to be passed to
this function.
data("crs", package = "omicRexposome") plotIntegration(crs)data("crs", package = "omicRexposome") plotIntegration(crs)
This method draws a baplor with the lambda score of each result in the given ResultSet.
plotLambda(object, width = 0.75) ## S4 method for signature 'ResultSet' plotLambda(object, width = 0.75)plotLambda(object, width = 0.75) ## S4 method for signature 'ResultSet' plotLambda(object, width = 0.75)
object |
An object of class ResultSet |
width |
(default |
A ggplot2 object
plotHits for a graphical representation of
the hits per analysys, tableLambda for the lambda
score per analysys, tableHits for the hists per analysys
data("asr", package = "omicRexposome") plotLambda(asr)data("asr", package = "omicRexposome") plotLambda(asr)
snpSet to a matrix of
a continuous variable.The function converts the categorical variable of SNPs to a continuous variable by normalizing each SNP as described in Abraham G. and Inouye M. 2014 (DOI: 10.1371/journal.pone.0093766).
snpToContinuous(snpSet, verbose = FALSE)snpToContinuous(snpSet, verbose = FALSE)
snpSet |
An object of class |
verbose |
If set to |
An matrix of the calls of the SNPs converted to a continuous
variable.
crossomics use this function
Given a threshold it counts the number of hits in each result in the given ResultSet.
tableHits(object, th = 0.05) ## S4 method for signature 'ResultSet' tableHits(object, th = 0.05)tableHits(object, th = 0.05) ## S4 method for signature 'ResultSet' tableHits(object, th = 0.05)
object |
An object of class ResultSet |
th |
(default |
A labeled numeric vector with the exposures and the number of hits.
tableLambda for the lambda score per analysys,
plotLambda for a graphical representation of
the lambda score per analysys, plotHits for a graphical
representation of the hists per analysys
data("asr", package = "omicRexposome") tableHits(asr)data("asr", package = "omicRexposome") tableHits(asr)
Compute lambda score on each result in the given ResultSet by using
lambdaClayton.
tableLambda(object, trim = 0.5) ## S4 method for signature 'ResultSet' tableLambda(object, trim = 0.5)tableLambda(object, trim = 0.5) ## S4 method for signature 'ResultSet' tableLambda(object, trim = 0.5)
object |
An object of class ResultSet |
trim |
(default |
Returns a data.frame having the exposures and the computed
lambda score.
A labeled numeric vector with the lambda score for each exposure.
tableHits for the number of hits per analysys,
plotHits for a graphical representation of the hists
per analysys, plotLambda for a graphical representation of
the lambda score per analysys
data("asr", package = "omicRexposome") tableLambda(asr)data("asr", package = "omicRexposome") tableLambda(asr)